@@ -1,4 +1,4 @@
-from helpers.segmentation import Segmentation
+from .segmentation import Segmentation
 
 def puzzle_to_internals(cells_str, clues):
   solution = [cell_str_to_marker(x) for x in cells_str]
