@@ -1,6 +1,10 @@
-from solve_seq import solve_seq
+from .schemas import PuzzleSchema
+from .solve_seq import solve_seq
+
+def solve(puzzle, validate_input = True):
+  if (validate_input):
+    PuzzleSchema().load(puzzle)
 
-def solve(puzzle):
   width = len(puzzle['cols'])
   height = len(puzzle['rows'])
 
