@@ -1,6 +1,6 @@
-from helpers.is_already_solved import is_already_solved
-from helpers.converter import puzzle_to_internals, internals_to_puzzle
-from helpers.identifiers import is_group, is_cross, is_empty, is_unidentified
+from .helpers.is_already_solved import is_already_solved
+from .helpers.converter import puzzle_to_internals, internals_to_puzzle
+from .helpers.identifiers import is_group, is_cross, is_empty, is_unidentified
 
 def solve_seq(cells_str, clues):
   if is_already_solved(cells_str):
